/**
  *  \file client/tiles/baseheader.cc
  */

#include <algorithm>
#include "client/tiles/baseheader.h"
#include "cpluslib/format.h"
#include "game/config.h"
#include "game/planet.h"
#include "resmgr/resid.h"
#include "util/nls.h"


WBaseScreenHeaderTile::WBaseScreenHeaderTile(GObjectType& type)
    : WControlScreenHeaderTile(type, bAuto + bAdd)
{ }

string_t
WBaseScreenHeaderTile::getTitle()
{
    return getObject()->getName();
}

string_t
WBaseScreenHeaderTile::getSubtitle()
{
    string_t result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject())) {
        int16 level = p->unit_scores.getScore(planet_score_definitions.lookupScore(ScoreId_ExpLevel));
        const char* fmt = (level >= 0
                           ? _("(Id #%d, %s)")
                           : _("(Id #%d)"));
        result = format(fmt, getObject()->getId(), getExperienceLevelName(level));
    }
    return result;
}

ResId
WBaseScreenHeaderTile::getPictureId()
{
    int max_tech = 0;
    int id = 0;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject())) {
        id = p->getId();
        if (p->hasBase()) {
            max_tech = std::max(std::max(p->getBaseTech(tl_Engine),
                                         p->getBaseTech(tl_Hull)),
                                std::max(p->getBaseTech(tl_Beam),
                                         p->getBaseTech(tl_Torpedo)));
        }
    }
    return ResId(res::base, max_tech, id);
}

