/**
  *  \file io/nullstream.cc
  *  \brief Null stream (data sink)
  */

#include "io/nullstream.h"

/** Constructor. */
NullStream::NullStream()
    : pos(0), size(0)
{ }

/** Destructor. */
NullStream::~NullStream()
{ }

std::size_t
NullStream::read(char* buffer, std::size_t nbytes)
{
    (void) buffer;
    (void) nbytes;
    return 0;
}

std::size_t
NullStream::write(const char* buffer, std::size_t nbytes)
{
    (void) buffer;
    pos += nbytes;
    if (pos > size)
        size = pos;
    return nbytes;
}

int
NullStream::getCapabilities() const
{
    return C_WRITE | C_SEEK;
}

bool
NullStream::seek(fpos_t pos)
{
    this->pos = pos;
    return true;
}

NullStream::fpos_t
NullStream::getSize()
{
    return size;
}

NullStream::fpos_t
NullStream::getPos()
{
    return pos;
}

string_t
NullStream::getName()
{
    return "<null>";
}
