/**
  *  \file tools/c2dump.h
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_TOOLS_C2DUMP_H
#define PCC_V2_TOOLS_C2DUMP_H

#include "cpluslib/string.h"

class Stream;

class DumpOutputReceiver {
 public:
    DumpOutputReceiver()
        { }
    virtual ~DumpOutputReceiver()
        { }

    virtual void startRecord(string_t header) = 0;
    virtual void addField(string_t name, string_t value) = 0;
    virtual void addUnparsedData(string_t formatted) = 0;
    virtual void endRecord() = 0;

    void addField(const char* name, string_t value);
};

class DumpBlockInput {
    const char* p;
    std::size_t size;
 public:
    DumpBlockInput(const char* p, std::size_t size);
    DumpBlockInput(DumpBlockInput& other, std::size_t rsize);
    ~DumpBlockInput();

    string_t    readByte();
    string_t    readWord();
    string_t    readLong();
    string_t    readCoordinate();
    string_t    readString(std::size_t length);
    string_t    readPascalString();
    std::size_t getRemainingSize() const;
    string_t    readUnparsed(std::size_t limit);

    int         peek(void* buffer, size_t size);
    int         read(void* buffer, size_t size);
    int         skip(size_t size);
};

void dumpRemainder(DumpBlockInput& bi, DumpOutputReceiver& r);

typedef void (*DumpParser)(Stream& s, DumpOutputReceiver& out);

/* c2dumpsimple.cc */
void parseShipFile(Stream&, DumpOutputReceiver&);
void parsePDataFile(Stream&, DumpOutputReceiver&);
void parseBDataFile(Stream&, DumpOutputReceiver&);
void parseGenFile(Stream&, DumpOutputReceiver&);

/* c2dumpspec.cc */
void parseHullSpec(Stream&, DumpOutputReceiver&);
void parseTorpSpec(Stream&, DumpOutputReceiver&);
void parseBeamSpec(Stream&, DumpOutputReceiver&);
void parseEngSpec(Stream&, DumpOutputReceiver&);
void parseTrueHull(Stream&, DumpOutputReceiver&);
void parseNameList(Stream&, DumpOutputReceiver&);
void parseXYPlan(Stream&, DumpOutputReceiver&);
void parseRaceNames(Stream&, DumpOutputReceiver&);

/* c2dumpextra.cc */
void parseTeams(Stream&, DumpOutputReceiver&);

#endif
